"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const ajv_1 = __importDefault(require("ajv"));
const ajv_merge_patch_1 = __importDefault(require("ajv-merge-patch"));
const browserify_bignum_1 = __importDefault(require("browserify-bignum"));
const schemas = __importStar(require("./schema"));
const validation_1 = require("./validation");
exports.validator = new ajv_1.default({ allErrors: true });
ajv_merge_patch_1.default(exports.validator);
exports.validator.addFormat('signature', data => /^[a-f0-9]{128}$/i.test(data));
exports.validator.addFormat('id', data => validation_1.isNumberString(data) && !validation_1.isGreaterThanMaxTransactionId(new browserify_bignum_1.default(data)));
exports.validator.addFormat('address', data => {
    try {
        validation_1.validateAddress(data);
        return true;
    }
    catch (error) {
        return false;
    }
});
exports.validator.addFormat('amount', validation_1.validateAmount);
exports.validator.addFormat('transferAmount', validation_1.validateTransferAmount);
exports.validator.addFormat('fee', validation_1.validateFee);
exports.validator.addFormat('publicKey', data => {
    try {
        validation_1.validatePublicKey(data);
        return true;
    }
    catch (error) {
        return false;
    }
});
exports.validator.addFormat('signedPublicKey', data => {
    try {
        const action = data[0];
        if (action !== '+' && action !== '-') {
            return false;
        }
        const publicKey = data.slice(1);
        validation_1.validatePublicKey(publicKey);
        return true;
    }
    catch (error) {
        return false;
    }
});
exports.validator.addFormat('additionPublicKey', data => {
    const action = data[0];
    if (action !== '+') {
        return false;
    }
    try {
        const publicKey = data.slice(1);
        validation_1.validatePublicKey(publicKey);
        return true;
    }
    catch (error) {
        return false;
    }
});
exports.validator.addKeyword('uniqueSignedPublicKeys', {
    type: 'array',
    compile: () => (data) => new Set(data.map((key) => key.slice(1))).size === data.length,
});
exports.validator.addSchema(schemas.baseTransaction);
//# sourceMappingURL=validator.js.map